# swagger-client
The FAIR Evaluator - automated testing of Web resources for their compliance with the FAIR Metrics

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.3.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import swagger_client
from swagger_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = swagger_client.CreateACollectionOfMaturityLevelTestsApi(swagger_client.ApiClient(configuration))
body = swagger_client.Collections() # Collections | register a new collection of FAIR Metrics (optional)

try:
    # Create a new collection of Metrics to be used for Evaluations
    api_response = api_instance.collections_post(body=body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CreateACollectionOfMaturityLevelTestsApi->collections_post: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://w3id.org/FAIR_Evaluator*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CreateACollectionOfMaturityLevelTestsApi* | [**collections_post**](docs/CreateACollectionOfMaturityLevelTestsApi.md#collections_post) | **POST** /collections | Create a new collection of Metrics to be used for Evaluations
*ExecuteAMaturityLevelEvaluationApi* | [**collections_collectionid_evaluate_post**](docs/ExecuteAMaturityLevelEvaluationApi.md#collections_collectionid_evaluate_post) | **POST** /collections/{collectionid}/evaluate | to register a new metric, send the smartURL to this endpiint
*RegisterANewMaturityLevelTestApi* | [**metrics_post**](docs/RegisterANewMaturityLevelTestApi.md#metrics_post) | **POST** /metrics | To register a new test, send the smartURL to this endpiint
*RetrieveCollectionsOfMaturityLevelTestsApi* | [**collections_get**](docs/RetrieveCollectionsOfMaturityLevelTestsApi.md#collections_get) | **GET** /collections | Retrieve all Metric Collections
*RetrieveASpecificMaturityTestCollectionApi* | [**collections_collectionid_get**](docs/RetrieveASpecificMaturityTestCollectionApi.md#collections_collectionid_get) | **GET** /collections/{collectionid} | Retrieve FAIR Metrics Collections by their Evaluator-id.
*RetrieveASpecificMaturityTestDescriptionApi* | [**metrics_metricid_get**](docs/RetrieveASpecificMaturityTestDescriptionApi.md#metrics_metricid_get) | **GET** /metrics/{metricid} | Retrieve FAIR Tests by their Evaluator-id.
*RetrieveAllKnownMaturityLevelTestsApi* | [**metrics_get**](docs/RetrieveAllKnownMaturityLevelTestsApi.md#metrics_get) | **GET** /metrics | Retrieve all FAIR Maturity Level Tests
*RetrieveAnExistingMaturityLevelEvaluationApi* | [**evaluations_evaluationid_result_get**](docs/RetrieveAnExistingMaturityLevelEvaluationApi.md#evaluations_evaluationid_result_get) | **GET** /evaluations/{evaluationid}/result | Retrieve the result of an existing FAIR Evaluation
*SearchMaturityTestsAndCollectionsByKeywordApi* | [**searches_myid_post**](docs/SearchMaturityTestsAndCollectionsByKeywordApi.md#searches_myid_post) | **POST** /searches/{myid} | Execute a search over Maturity Indicator Test descriptions and Collection descriptions
*SearchMaturityTestsAndCollectionsByKeywordApi* | [**searches_post**](docs/SearchMaturityTestsAndCollectionsByKeywordApi.md#searches_post) | **POST** /searches | Create a new search URI to POST your search terms

## Documentation For Models

 - [Collections](docs/Collections.md)
 - [CollectionsArray](docs/CollectionsArray.md)
 - [CollectionsResult](docs/CollectionsResult.md)
 - [ErrorResult](docs/ErrorResult.md)
 - [Errorblock](docs/Errorblock.md)
 - [Evaluate](docs/Evaluate.md)
 - [EvaluationResult](docs/EvaluationResult.md)
 - [Ids](docs/Ids.md)
 - [Metrics](docs/Metrics.md)
 - [MetricsArray](docs/MetricsArray.md)
 - [MetricsList](docs/MetricsList.md)
 - [MetricsResult](docs/MetricsResult.md)
 - [SearchSchema](docs/SearchSchema.md)
 - [Searchinput](docs/Searchinput.md)
 - [Searchresult](docs/Searchresult.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author

mark.wilkinson@upm.es
